from unittest import TestCase
from elang.word2vec.builder import (
    build_from_wikipedia,
    build_from_wikipedia_branch,
    build_from_wikipedia_random,
)


class TestBuildRandomly(TestCase):
    def test_build_random(self):
        pass
